# Projet générateur de site statique

## Présentation du projet

La finalité de ce projet était de développer un outil permettant la conversion de fichiers markdown en fichiers HTML.

## 

<!--stackedit_data:
eyJoaXN0b3J5IjpbMTk2NDIzMDc1XX0=
-->